@@ -2,14 +2,14 @@
 from __future__ import absolute_import, unicode_literals
 import celery
 from vstutils.management.commands._base import BaseCommand as _BaseCommand
-from ..utils import AnsibleArgumentsReference
+from ..constants import ANSIBLE_REFERENCE
 
 
 class BaseCommand(_BaseCommand):
 
     def _get_versions(self):
-        versions = super(BaseCommand, self)._get_versions()
-        versions['ansible'] = AnsibleArgumentsReference().version
+        versions = super()._get_versions()
+        versions['ansible'] = ANSIBLE_REFERENCE.version
         versions['celery'] = celery.__version__
         return versions
 
